@@ -1,4 +1,4 @@
-''' I2C Interface '''
+""" I2C Interface """
 from .types import I2CError, I2CBase
 from .i2c import I2C
 
